import os
def path_file_existed_or_create(path_or_file=[]):
    """
    目录或文件是否存在，不存在就创建。
    传入参数为列表
    """
    # 创建目录
    if len(path_or_file) == 0:
        pass
    for path_or_file in path_or_file:
        if str(path_or_file)[-1] == "/" or str(path_or_file)[-1] == "\\":
            # 这是个目录
            if not os.path.exists(path_or_file):
                os.makedirs(path_or_file)
                # os.chmod(path_or_file, "rw")
        else:
            # 这是个文件
            if not os.path.exists(path_or_file):
                f = open(path_or_file,'w')
                f.close()

if __name__ == '__main__':
    assert_path_files = ['./video/',
                        './picture/color/',
                        './picture/gray/',
                        './picture/color/mtianyan.txt',
                        ]
    path_file_existed_or_create(assert_path_files)


# -*- coding: utf-8 -*-
import subprocess


class Aria2DownloadTool:
    def __init__(self, aria2_path):
        self.aria2_path = aria2_path

    def download(self, download_url, filename=None, dir=None):
        aria2_opts = [self.aria2_path + '/aria2c', download_url]
        if filename:
            aria2_opts.extend(('--out', filename))
        if dir:
            aria2_opts.append(('--dir ', dir))
        # 这里只负责提交下载任务使用Popen 不阻塞等待返回，实际下载进度由YAAW维护。
        exit_code = subprocess.call(aria2_opts, shell=True)
        if exit_code != 0:
            raise Exception('aria2c exited abnormally')


def openAria2RPC(aria2_path):
    subprocess.call("\"" + aria2_path + "/aria2c\"   --conf-path=aria2.conf -D")

def start_webui_aria2(port):
    import os
    # print(os.getcwd())
    plugins_path = os.path.join(os.path.dirname(os.path.dirname(os.path.realpath(__file__))),'plugins')
    webui_aria2_path = os.path.join(plugins_path,'webui-aria2')
    # print(plugins_path)
    # print(webui_aria2_path)
    os.chdir(webui_aria2_path)
    # 使用call 父进程会等待子进程直到完成，而使用popen不指定就不会阻塞
    subprocess.Popen('python -m http.server {0}'.format(port),shell=True)
    start_browser(port)

def start_browser(port):
    import webbrowser
    url = 'http://127.0.0.1:{0}'.format(port)
    webbrowser.open(url, new=0, autoraise=True)

if __name__ == '__main__':
    # aria2_path = "./"
    
    # openAria2RPC(aria2_path)
    # download_url = "http://groups.inf.ed.ac.uk/vision/CAVIAR/CAVIARDATA1/Walk2/Walk2.mpg"
    # filename = "master.zip";
    # dir = "./";
    # tool = Aria2DownloadTool(aria2_path)
    # tool.download(download_url, filename, dir);
    start_webui_aria2(9999)


from bs4 import BeautifulSoup
import requests
import re
from mtianyan.path_helper import path_file_existed_or_create

def get_download_list_from_fileformat(page_url,file_format,merge=False):
    assert_path = ['./download_list/',]
    path_file_existed_or_create(assert_path) 
    response = requests.get(page_url)
    html = BeautifulSoup(response.text, "lxml")
    if merge == True:
        file_reg = ''
        flag = 0
        for file in file_format:
            if flag ==  0:
                file_reg = file
                flag = 1
            else:
                file_reg = file_reg +'|'+ file
        links_all = html.find_all('a', href=re.compile(file_reg))
        f = open('./download_list/merge_list.txt', 'a')
        for x in range(1, len(links_all)):
            f.write(links_all[x]['href'] + '\n')
        print("./download_list/merge_list has been saved!")
        f.close()
    elif merge == False:
        for file_reg in file_format:
            links = html.find_all('a', href=re.compile(file_reg))
            f = open('./download_list/{0}_list.txt'.format(file_reg[1:]), 'a')
            for x in range(1, len(links)):
                f.write(links[x]['href'] + '\n')
            f.close()
            print('./download_list/{0}_list.txt'.format(file_reg[1:]) + 'has been saved!')

if __name__ == '__main__':
    file_format = ['.mpg',
            '.xml',
            '.tar.gz',]
    page_url = 'http://groups.inf.ed.ac.uk/vision/CAVIAR/CAVIARDATA1/'

    get_download_list_from_fileformat(page_url,file_format)


import os.path
filepathlist=[]
filenamelist=[]
def processDirectory ( args, dirname, filenames ):
    for filename in filenames:
          file_path=os.path.join(dirname,filename)
          if os.path.isfile(file_path):
            filepathlist.append(file_path)
            filenamelist.append(filename)

def getpatch(path):
    os.path.walk(r'%s'%path, processDirectory, None )
    return filepathlist

getpatch('H:\CodePath\NoteBook\uber_input')
fw = open('data_list.txt','w')
for item in filenamelist:
    fw.write(item+'\n')



class girlfriend(object):
    """docstring for girlfriend"""
    def __init__(self):
        self.name = "zhaotudou"
def love():
    print("love zhaotudou forever")

from random import randint


def colored_message(message):
    return '\033[0;{};01m{message}\033[0m'.format(randint(30, 37), message=message)

        


from setuptools import setup, find_packages
from os.path import join, isfile
from os import walk

def package_files(directories):
    paths = []
    for item in directories:
        if isfile(item):
            paths.append(join('..', item))
            continue
        for (path, directories, filenames) in walk(item):
            for filename in filenames:
                paths.append(join('..', path, filename))
    return paths

setup(
    name = "mtianyan",
    version = "0.0.8",
    keywords = ("pip", "mtianyan"),
    description = "mtianyan's tool",
    long_description = "mtianyan's tool",
    license = "MIT Licence",

    url = "http://blog.mtianyan.cn",
    author = "mtianyan",
    author_email = "mtianyan@qq.com",

    packages = find_packages(),
        package_data={
        '': package_files([
            'mtianyan/plugins/',
            'mtianyan/download_helper/'
        ])
    },
    platforms = "any",
    install_requires = ["beautifulsoup4", "requests"]
)



from random import randint


def colored_message(message):
    return '\033[0;{};01m{message}\033[0m'.format(randint(30, 37), message=message)
    
class CV:
    def __str__(self):
        return '田岩的简历'

    def show(self):
        print(colored_message('基本信息:'))
        for k, v in self.basic:
            print('\t{}: {}'.format(k.ljust(12), v))

        print(colored_message('毕业学校:'))
        for k, v in self.collage:
            print('\t{}: {}'.format(k.ljust(12), v))

        print(colored_message('工作经历:'))
        for index, career in enumerate(self.career):
            print(colored_message('\t[{}]:'.format(index + 1)))
            for k, v in career:
                print('\t{}: {}'.format(k.ljust(12), v))

        print(colored_message('项目经历:'))
        for index, project in enumerate(self.projects):
            print(colored_message('\t[{}]:'.format(index + 1)))
            for k, v in project:
                print('\t{}: {}'.format(k.ljust(12), v))

        print(colored_message('个人技能:'))
        for index, skill in enumerate(self.skills):
            print(colored_message('\t[{}]:'.format(index + 1)))
            for k, v in skill:
                print('\t{}: {}'.format(k.ljust(12), v))

    @property
    def basic(self):
        return [('name', '田岩'),
                ('sex', '男'),
                ('birthday', '1997'),
                ('phone', 'echo MTgwOTI2NyoqKiogDQo= | base64 -d'),
                ('email', 'mtianyan@qq.com'),
                ('address', '陕西西安'),
                ('github', 'https://github.com/mtianyan'),
                ('blog', 'http://blog.mtianyan.cn')]

    @property
    def collage(self):
        return [('school', '云南大学'),
                ('degree', '本科'),
                ('period', '2014.09 - 2018.06'),
                ('major', '软件工程')]

    @property
    def career(self):
        return [(('company', '家里蹲有限公司'),
                 ('period', '一直 - 至今'),
                 ('position', 'Python瞎折腾工程师'),
                 ('duty', '网站开发, 文档编写, 爬虫瞎爬,服务器运维'))]

    @property
    def projects(self):
        return [(('name', 'mtianyan慕课小站'),
                 ('description', ('Django2.0 + Mysql + xadmin')),
                 ('duty', '后端开发'),
                 ('url', 'http://mxonline.mtianyan.cn')),
                (('name', 'mtianyan搜索'),
                 ('description', ('Django + ELasticSearch + Scrapy')),
                 ('duty', '爬虫 + 搜索程序员'),
                 ('url', 'http://search.mtianyan.cn')),
                (('name', '弹幕电影'),
                 ('description', 'Flask开发的弹幕电影网站'),
                 ('duty', '后端开发'),
                 ('url', 'http://movie.mtianyan.cn')),
                (('name', 'vueshop生鲜超市'),
                 ('description', 'vue + Django restframework + xadmin'),
                 ('duty', '后端开发'),
                 ('url', 'http://vueshop.mtianyan.cn/index'))]

    @property
    def skills(self):
        return [(('name', '后端开发'),
                 ('description', '利用Python相关技术快速完成后端开发, 部署')),
                (('name', '网络爬虫'),
                 ('description', '利用Python相关技术快速完成网络爬虫编写')),
                (('name', '系统运维'),
                 ('description', '掌握Linux相关环境部署运维技能')),
                (('name', '机器学习 & 深度学习'),
                 ('description', '正在努力学习'))]


cv = CV()
cv.show()


# -*- coding: utf-8 -*-
import requests
import os
import time
import base64
from mtianyan.path_helper import path_file_existed_or_create

class Aria2JsonRpc(object):
    def __init__(self, rpc_url, arai2_path):
        # assert_path = ['./dir/',
        #                 './out/']
        # path_file_existed_or_create(assert_path)
        # RPC采用客户机/服务器模式。 请求程序就是一个客户机，而服务提供程序就是一个服务器。 首先，调用进程发送一个有进程参数的调用信息到服务进程，然后等待应答信息。
        # 初始化时指定rpc地址: http://localhost:6800/jsonrpc?tm=%s
        self.rpc_url = rpc_url
        # 指定可执行文件地址: ./
        self.arai2_path = arai2_path
        # 如果rpc服务未开启, 那么启动。
        if not self.isAlive():
            self.startAria2Rpc()


    def isAlive(self):
        """
        判断rpc服务是否激活
        """
        # 生成一个payload: payload 可以理解为一系列信息中最为关键的信息。
        payload = {"jsonrpc": "2.0", "method": "aria2.tellActive", "id": 1}
        # 时间戳签名
        tm = int(time.time() * 1000)
        url = self.rpc_url % str(tm)
        try:
            r = requests.get(url, payload)
            return r.status_code == 200
        except Exception:
            return False


    def startAria2Rpc(self):
        """
        开启rpc服务
        """
        import subprocess, sys
        if sys.platform == "linux":
            # 启动命令写入文件
            download_helper_path = os.path.join(os.path.dirname(os.path.dirname(os.path.realpath(__file__))),'download_helper')
            bat_path = download_helper_path + '/startAria2Rpc.sh'
            print(bat_path)
            launch_file = open(bat_path, "w")
            new_bash = "aria2c --conf-path=aria2.conf"
            launch_file.write(new_bash)
            launch_file.close()
            # aria2 使用cmd打开
            os.chdir(download_helper_path)
            # os.Popen(bat_path)
            subprocess.Popen('sh startAria2Rpc.sh',shell=True)
        else:
            # 启动命令写入文件
            download_helper_path = os.path.join(os.path.dirname(os.path.dirname(os.path.realpath(__file__))),'download_helper')
            bat_path = download_helper_path + '\startAria2Rpc.bat'
            launch_file = open(bat_path, "w")
            # print(bat_path)
            new_cmd = "aria2c.exe --conf-path=aria2.conf -D"
            launch_file.write(new_cmd)
            launch_file.close()
            # aria2 使用cmd打开
            os.chdir(download_helper_path)
            os.startfile(bat_path)
            # print('****')
            # 进程挂起3秒保证aria2打开完毕
            time.sleep(3)

        

    def execuetJsonRpcCmd(self, method, param=None):
        """
        执行命令函数
        """
        payload = {"jsonrpc": "2.0", "method": method, "id": 1, "params": param}
        payloads = [payload]
        tm = int(time.time() * 1000)
        url = self.rpc_url % str(tm)
        print(payloads)
        r = requests.post(url, None, payloads)
        print(r.text)
        return r.status_code

    

    def addUris(self, urls, dir=None, out=None):
        params = []
        download_config = {}
        if dir:
            download_config["dir"] = dir
        if out:
            download_config["out"] = out
        params.append(urls)
        params.append(download_config)
        print(self.execuetJsonRpcCmd("aria2.addUri", params))

    def addTorrent(self, path, dir=None, out=None):
        bits = open(path, "rb").read()
        torrent = base64.b64encode(bits)
        params = []
        download_config = {"dir": dir, "out": out}
        params.append(torrent)
        params.append([])
        params.append(download_config)
        print(self.execuetJsonRpcCmd("aria2.addTorrent", params))

def via_urls(download_list,dir,filename=None):
    aria2_path = "./"
    rpc_url = "http://localhost:6800/jsonrpc?tm=%s"
    # 启动服务
    rpcClient = Aria2JsonRpc(rpc_url, aria2_path)
    os_path = os.getcwd()
    download_path = os.path.join(os_path,dir[2:])
    for url in download_list:
        # 添加下载任务
        rpcClient.addUris([url],download_path,filename)

if __name__ == '__main__':
    magnet = ['http://groups.inf.ed.ac.uk/vision/CAVIAR/CAVIARDATA1/Browse3/Browse3_jpg.tar.gz',
                'http://groups.inf.ed.ac.uk/vision/CAVIAR/CAVIARDATA1/Browse4/Browse4_jpg.tar.gz']
    rpc_url = "http://localhost:6800/jsonrpc?tm=%s"
    aria2_path = "./"
    # 启动服务
    rpcClient = Aria2JsonRpc(rpc_url, aria2_path)
    # 添加下载任务
    # rpcClient.addUris(magnet,'./dir/')
    # via_urls(magnet,'./dir')
    # startAria2Rpc()
